import { Toast, Icon, Popup, Dialog } from 'vant'
import {
  defineComponent,
  onMounted,
  reactive,
  nextTick,
  onUnmounted,
  ref,
  watch,
  Transition,
  computed
} from 'vue'
import iconBack from './image/back.svg'
import styles from './index.module.less'
import 'plyr/dist/plyr.css'
import request from '@/helpers/request'
import { state } from '@/state'
import { useRoute } from 'vue-router'
import { postMessage, promisefiyPostMessage } from '@/helpers/native-message'
import MusicScore from './component/musicScore'
import iconDian from './image/icon-dian.svg'
import iconPoint from './image/icon-point.svg'
import {
  iconUp,
  iconDown,
  // iconPen,
  iconTouping,
  iconMenu
} from './image/icons.json'
import Points from './component/points'
import { browser } from '@/helpers/utils'
import { Vue3Lottie } from 'vue3-lottie'
import playLoadData from './datas/data.json'
import { usePageVisibility } from '@vant/use'
import PlayRecordTime from './playRecordTime'
// import { handleCheckVip } from '../hook/useFee'
import OGuide from './component/o-guide'
import Tool, { ToolItem, ToolType } from './component/tool'
import Pen from './component/tools/pen'
// import VideoItem from './component/video-item';
import VideoPlay from './component/video-play'

export default defineComponent({
  name: 'CoursewarePlay',
  setup() {
    const pageVisibility = usePageVisibility()
    /** 页面显示和隐藏 */
    watch(
      () => pageVisibility.value,
      value => {
        if (value == 'hidden') {
          handleStop()
        }
      }
    )
    /** 设置播放容器 16:9 */
    const parentContainer = reactive({
      width: '100vw'
    })
    const setContainer = () => {
      const min = Math.min(screen.width, screen.height)
      const max = Math.max(screen.width, screen.height)
      const width = min * (16 / 9)
      if (width > max) {
        parentContainer.width = '100vw'
        return
      } else {
        parentContainer.width = width + 'px'
      }
    }
    const handleInit = (type = 0) => {
      //设置容器16:9
      setContainer()
      // 横屏
      postMessage(
        {
          api: 'setRequestedOrientation',
          content: {
            orientation: type
          }
        },
        () => {
          // console.log(234);
        }
      )
      // 头,包括返回箭头
      // postMessage({
      //   api: 'setTitleBarVisibility',
      //   content: {
      //     status: type
      //   }
      // })
      // 安卓的状态栏
      postMessage({
        api: 'setStatusBarVisibility',
        content: {
          isVisibility: type
        }
      })
      // 进入页面设置常量
      postMessage({
        api: 'keepScreenLongLight',
        content: {
          isOpenLight: type ? true : false
        }
      })
    }
    handleInit()
    onUnmounted(() => {
      handleInit(1)
      window.removeEventListener('message', iframeHandle)
    })

    const route = useRoute()
    const headeRef = ref()
    const data = reactive({
      detail: null as any,
      knowledgePointList: [] as any,
      itemList: [] as any,
      showHead: true,
      isCourse: false,
      isRecordPlay: false,
      videoRefs: {},

      videoState: 'init' as 'init' | 'play',
      videoItemRef: null as any,
      animationState: 'start' as 'start' | 'end'
    })
    const activeData = reactive({
      isAutoPlay: true, // 是否自动播放
      nowTime: 0,
      model: true, // 遮罩
      isAnimation: true, // 是否动画
      videoBtns: true, // 视频
      currentTime: 0,
      duration: 0,
      timer: null as any,
      item: null as any
    })
    // 获取缓存路径
    const getCacheFilePath = async (material: any) => {
      const res = await promisefiyPostMessage({
        api: 'getCourseFilePath',
        content: {
          url: material.content,
          localPath: '',
          materialId: material.materialId,
          updateTime: material.updateTime,
          type: material.typeCode // SONG VIDEO IMAGE
        }
      })
      // console.log('缓存路径返回', res)
      return res
    }
    // 获取当前课程是否签退
    // const getCourseSchedule = async () => {
    //   if (!route.query.courseId) return;
    //   try {
    //     const res = await request.get(
    //       `${state.platformApi}/courseSchedule/detail/${route.query.courseId}`,
    //       {
    //         hideLoading: true
    //       }
    //     );
    //     if (res?.data) {
    //       data.isCourse =
    //         res.data.status === 'ING' && state.platformType == 'TEACHER'
    //           ? true
    //           : false;
    //       // data.isRecordPlay = Date.now() > dayjs(res.data.startTime).valueOf()
    //     }
    //   } catch (e) {
    //     console.log(e);
    //   }
    // };
    const getTempList = async (materialList: any, name: any) => {
      const list: any = []
      const browserInfo = browser()
      for (let j = 0; j < materialList.length; j++) {
        const material = materialList[j]
        //请求本地缓存
        if (browserInfo.isApp && ['VIDEO', 'IMG'].includes(material.typeCode)) {
          const localData: any = await getCacheFilePath(material)

          if (localData?.content?.localPath) {
            material.url = material.content
            material.content = localData.content.localPath
          } else {
            material.url = material.content + '?t=' + +new Date()
            material.content = material.content + '?t=' + +new Date()
          }
        }

        list.push({
          ...material,
          iframeRef: null,
          videoEle: null,
          tabName: name,
          autoPlay: false, //加载完成是否自动播放
          isprepare: false, // 视频是否加载完成
          isRender: false // 是否渲染了
        })
      }
      return list
    }
    const getItemList = async () => {
      const list: any = []

      for (let i = 0; i < data.knowledgePointList.length; i++) {
        const item = data.knowledgePointList[i]
        if (item.materialList && item.materialList.length > 0) {
          const tempList = await getTempList(item.materialList, item.name)
          list.push(...tempList)
        }

        // 第二层级
        if (item.children && item.children.length > 0) {
          const childrenList = item.children || []
          for (let j = 0; j < childrenList.length; j++) {
            const childItem = childrenList[j]
            const tempList = await getTempList(
              childItem.materialList,
              childItem.name
            )
            list.push(...tempList)
          }
        }
      }

      // console.log(list, 'list')

      let _firstIndex = list.findIndex(
        (n: any) =>
          n.knowledgePointMaterialRelationId == route.query.kId ||
          n.materialId == route.query.kId
      )
      _firstIndex = _firstIndex > -1 ? _firstIndex : 0
      const item = list[_firstIndex]

      // console.log(_firstIndex, '_firstIndex', route.query.kId, 'route.query.kId', item)
      // 是否自动播放
      if (activeData.isAutoPlay) {
        item.autoPlay = true
      }
      popupData.activeIndex = _firstIndex
      popupData.playIndex = _firstIndex
      popupData.tabName = item.tabName
      popupData.tabActive = item.knowledgePointId
      popupData.itemActive = item.id
      popupData.itemName = item.name
      nextTick(() => {
        data.itemList = list
        checkedAnimation(popupData.activeIndex)
        postMessage({
          api: 'courseLoading',
          content: {
            show: false,
            type: 'fullscreen'
          }
        })
        setTimeout(() => {
          data.animationState = 'end'
        }, 500)
      })
    }
    const getDetail = async () => {
      try {
        // const res: any = await request.get(
        //   state.platformApi +
        //     `/lessonCourseware/getLessonCourseDetail/${route.query.id}`,
        //   {
        //     hideLoading: true
        //   }
        // )
        const res = {
          status: true,
          data: {
            updateTime: '2023-09-22 22:17:43',
            createTime: '2023-09-11 15:43:18',
            lockFlag: false,
            lessonCoursewareId: 1000101,
            lessonTrainingId: 0,
            lessonTrainingName: '',
            lessonDurationSecond: 0,
            lessonOrder: 1,
            lockEnable: false,
            knowledgePointIds: '',
            accessScope: 0,
            knowledgePointList: [
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓乐器安装前言-打击乐- L1-1-1-讲话',
                    knowledgePointMaterialRelationId: 1701139355188412400,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030622,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '安装前言',
                    id: 1081414,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/3小军鼓乐器安装前言-打击乐-L1-1-1-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 1,
                totalMaterialTimeSecond: 0,
                name: '安装前言',
                id: 1030622
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '了解小军鼓的二个部件-打击乐- L1-1-2-讲话',
                    knowledgePointMaterialRelationId: 1701139355192606700,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030623,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '了解小军鼓的二个部件',
                    id: 1081415,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/4了解小军鼓的二个部件-打击乐-L1-1-2-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 2,
                totalMaterialTimeSecond: 0,
                name: '了解小军鼓的二个部件',
                id: 1030623
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '鼓架组装-打击乐- L1-1-3-A1-讲话',
                    knowledgePointMaterialRelationId: 1701139355192606700,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030624,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓的组装1',
                    id: 1081416,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/5鼓架组装-打击乐-L1-1-3-A1-讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '鼓架组装-打击乐- L1-1-3-A2-讲话',
                    knowledgePointMaterialRelationId: 1701139355192606700,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030624,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓的组装2',
                    id: 1081417,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/6鼓架组装-打击乐-L1-1-3-A2-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 3,
                totalMaterialTimeSecond: 0,
                name: '鼓架组装',
                id: 1030624
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓放置-打击乐- L1-1-4-A1-讲话',
                    knowledgePointMaterialRelationId: 1701139355192606700,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030625,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓放置1',
                    id: 1081418,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/9小军鼓放置-打击乐-L1-1-4-A1-讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓放置-打击乐- L1-1-4-A2-讲话',
                    knowledgePointMaterialRelationId: 1701139355196801000,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030625,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓放置2',
                    id: 1081419,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/11小军鼓放置-打击乐-L1-1-4-A2-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 4,
                totalMaterialTimeSecond: 0,
                name: '小军鼓放置',
                id: 1030625
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓放置-打击乐- L1-1-5-A1-讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030626,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓收纳1',
                    id: 1081420,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/12小军鼓放置-打击乐-L1-1-5-A1-讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓放置-打击乐- L1-1-5-A2-讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030626,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '小军鼓收纳2',
                    id: 1081421,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/13小军鼓放置-打击乐-L1-1-5-A2-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 5,
                totalMaterialTimeSecond: 0,
                name: '小军鼓收纳',
                id: 1030626
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '结尾-打击乐-L1-1-7-讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030627,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '安装结束语',
                    id: 1081422,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/191结尾-打击乐-L1-1-7-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 6,
                totalMaterialTimeSecond: 0,
                name: '安装结束语',
                id: 1030627
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓演奏姿势前言-打击乐-L1-1-1-讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030628,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '演奏姿势前言',
                    id: 1081423,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/25小军鼓演奏姿势前言-打击乐-L1-1-1-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 7,
                totalMaterialTimeSecond: 0,
                name: '演奏姿势前言',
                id: 1030628
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A1讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '调节小军鼓高度',
                    id: 1081424,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/26小军鼓的演奏姿势-打击乐-L1-1-2-A1讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A2讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '演奏姿势：放松姿势与准备姿势介绍',
                    id: 1081425,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/27小军鼓的演奏姿势-打击乐-L1-1-2-A2讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A3讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '准备姿势：站姿',
                    id: 1081426,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/28小军鼓的演奏姿势-打击乐-L1-1-2-A3讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A4讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '准备姿势：鼓棒握姿',
                    id: 1081427,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/29小军鼓的演奏姿势-打击乐-L1-1-2-A4讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A5讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '准备姿势：鼓棒与小军鼓距离',
                    id: 1081428,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/30小军鼓的演奏姿势-打击乐-L1-1-2-A5讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-2-A6讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030629,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '注意事项',
                    id: 1081429,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/31小军鼓的演奏姿势-打击乐-L1-1-2-A6讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 8,
                totalMaterialTimeSecond: 0,
                name: '小军鼓的演奏姿势',
                id: 1030629
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的演奏姿势-打击乐- L1-1-3-A-结尾',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030630,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '演奏姿势结束语',
                    id: 1081430,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/32小军鼓的演奏姿势-打击乐-L1-1-3-A-结尾.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 9,
                totalMaterialTimeSecond: 0,
                name: '演奏姿势结束语',
                id: 1030630
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓乐器保养前言-打击乐-L1-1-1-讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030631,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '保养前言',
                    id: 1081431,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/18小军鼓乐器保养前言-打击乐-L1-1-1-讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 10,
                totalMaterialTimeSecond: 0,
                name: '保养前言',
                id: 1030631
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的保养-打击乐- L1-1-2-A1讲话',
                    knowledgePointMaterialRelationId: 1701139355200995300,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030632,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '保养介绍：小军鼓清洁',
                    id: 1081432,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/19小军鼓的保养-打击乐-L1-1-2-A1讲话.mp4',
                    typeCode: 'VIDEO'
                  },
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的保养-打击乐- L1-1-2-A2讲话',
                    knowledgePointMaterialRelationId: 1701139355209384000,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030632,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '保养介绍：金属带开关调节',
                    id: 1081433,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/20小军鼓的保养-打击乐-L1-1-2-A2讲话.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 11,
                totalMaterialTimeSecond: 0,
                name: '小军鼓的保养',
                id: 1030632
              },
              {
                children: null,
                materialList: [
                  {
                    updateTime: '2023-09-11 15:43:18',
                    sn: '小军鼓的保养-打击乐- L1-1-3-A-结尾（20秒）',
                    knowledgePointMaterialRelationId: 1701139355209384000,
                    adviseStudyTimeSecond: 0,
                    knowledgePointId: 1030633,
                    courseTypeCode: 'PERCUSSION_SINGLE',
                    name: '保养结束语',
                    id: 1081434,
                    type: 0,
                    content:
                      'https://courseware.lexiaoya.cn/21小军鼓的保养-打击乐-L1-1-3-A-结尾.mp4',
                    typeCode: 'VIDEO'
                  }
                ],
                sortNo: 12,
                totalMaterialTimeSecond: 0,
                name: '结束语',
                id: 1030633
              },
              {
                children: [
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身前言-打击乐- L1-1-讲话',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030635,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习-前言',
                        id: 1081435,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/36手腕热身前言-打击乐-L1-1-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 13,
                    totalMaterialTimeSecond: 0,
                    name: '前言',
                    id: 1030635
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身-打击乐- L1-1-2-A1-讲话',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习-讲话',
                        id: 1081436,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/156手腕热身-打击乐-L1-1-2-A1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身一（举高高）-打击乐- L1-1-2-B1-讲话',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习1-6个动作-讲话1',
                        id: 1081437,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/157手腕热身一（举高高）-打击乐-L1-1-2-B1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身一（举高高）-打击乐- L1-1-2-B2-讲话1',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习1-举高高-讲话2',
                        id: 1081438,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/158手腕热身一（举高高）-打击乐-L1-1-2-B2-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身一（举高高）-打击乐- L1-1-2-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习1-举高高-第一次练习',
                        id: 1081439,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/159手腕热身一（举高高）-打击乐-L1-1-2-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身一（举高高）-打击乐- L1-1-2-B2-讲话2',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习1-举高高-讲话3',
                        id: 1081440,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/160手腕热身一（举高高）-打击乐-L1-1-2-B2-讲话2.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身一（举高高）-打击乐- L1-1-2-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030636,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习1-举高高-第二次练习',
                        id: 1081441,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/159手腕热身一（举高高）-打击乐-L1-1-2-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 14,
                    totalMaterialTimeSecond: 0,
                    name: '手腕热身一（举高高）',
                    id: 1030636
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身二（推手手）-打击乐- L1-1-2-C1-讲话',
                        knowledgePointMaterialRelationId: 1701139355209384000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030637,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习2-推手手-讲话1',
                        id: 1081442,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/162手腕热身二（推手手）-打击乐-L1-1-2-C1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身二（推手手）-打击乐- L1-1-2-C2-讲话1',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030637,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习2-推手手-讲话2',
                        id: 1081443,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/163手腕热身二（推手手）-打击乐-L1-1-2-C2-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身二（推手手）-打击乐- L1-1-2-C2-示范',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030637,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习2-推手手-练习',
                        id: 1081444,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/164手腕热身二（推手手）-打击乐-L1-1-2-C2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身二（推手手）-打击乐- L1-1-2-C2-讲话2',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030637,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习2-推手手-讲话3',
                        id: 1081445,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/160手腕热身一（举高高）-打击乐-L1-1-2-B2-讲话2.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身二（推手手）-打击乐- L1-1-2-C2-示范',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030637,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习2-推手手-第二次练习',
                        id: 1081446,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/164手腕热身二（推手手）-打击乐-L1-1-2-C2-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 15,
                    totalMaterialTimeSecond: 0,
                    name: '手腕热身二（推手手）',
                    id: 1030637
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身三（转圈圈）-打击乐- L1-3-2-B1-讲话',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030638,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '讲解2个步骤',
                        id: 1081447,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/255手腕热身三（转圈圈）-打击乐-L1-3-2-B1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身三（转圈圈）-打击乐- L1-3-2-B2-讲话1',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030638,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习3-转圈圈-讲话1',
                        id: 1081448,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/256手腕热身三（转圈圈）-打击乐-L1-3-2-B2-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身三（转圈圈）-打击乐- L1-3-2-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030638,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习3-转圈圈-第一次练习',
                        id: 1081449,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/257手腕热身三（转圈圈）-打击乐-L1-3-2-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身三（转圈圈）-打击乐- L1-3-2-B2-讲话2',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030638,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习3-转圈圈-讲话2',
                        id: 1081450,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/258手腕热身三（转圈圈）-打击乐-L1-3-2-B2-讲话2.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身三（转圈圈）-打击乐- L1-3-2-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030638,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习3-转圈圈-第二次练习',
                        id: 1081451,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/257手腕热身三（转圈圈）-打击乐-L1-3-2-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 16,
                    totalMaterialTimeSecond: 0,
                    name: '手腕热身三（转圈圈）',
                    id: 1030638
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响）-打击乐-L1-5-2-B1-讲话',
                        knowledgePointMaterialRelationId: 1701139355213578200,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响-前言',
                        id: 1081452,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/379手腕热身四（一个巴掌拍的响）-打击乐-L1-5-2-B1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响）-打击乐-L1-5-2-B2-讲话',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '讲解两个步骤',
                        id: 1081453,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/380手腕热身四（一个巴掌拍的响）-打击乐-L1-5-2-B2-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响1拍教学）-打击乐-L1-5-2-B3-讲话1',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响- 练习一拍1次',
                        id: 1081454,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/381手腕热身四（一个巴掌拍的响1拍教学）-打击乐-L1-5-2-B3-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响半拍教学）-打击乐-L1-5-2-B3-讲话2',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响-练习一拍2次',
                        id: 1081455,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/382手腕热身四（一个巴掌拍的响半拍教学）-打击乐-L1-5-2-B3-讲话2.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响4遍）-打击乐-L1-5-2-B3-讲话3',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响-完整练习-讲话',
                        id: 1081456,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/383手腕热身四（一个巴掌拍的响4遍）-打击乐-L1-5-2-B3-讲话3.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响4遍）-打击乐-L1-5-2-B3-示范1',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响- 完整练习-练习',
                        id: 1081457,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/384手腕热身四（一个巴掌拍的响4遍）-打击乐-L1-5-2-B3-示范1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响放松）-打击乐-L1-5-2-B3-讲话4',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响-放松练习-讲话',
                        id: 1081458,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/385手腕热身四（一个巴掌拍的响放松）-打击乐-L1-5-2-B3-讲话4.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身四（一个巴掌拍的响放松）-打击乐-L1-5-2-B3-示范2',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030639,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '手腕热身练习4-一个巴掌拍的响-放松练习-练习',
                        id: 1081459,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/386手腕热身四（一个巴掌拍的响放松）-打击乐-L1-5-2-B3-示范2.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 17,
                    totalMaterialTimeSecond: 0,
                    name: '手腕热身四（一个巴掌拍的响）',
                    id: 1030639
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身（连贯）-打击乐-L1-1-6-A1-讲话',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030640,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '完整手腕热身/讲话',
                        id: 1081460,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/61手腕热身（连贯）-打击乐-L1-1-6-A1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '手腕热身（连贯）-打击乐-L1-6-2-A1-示范',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030640,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '完整手腕热身/练习',
                        id: 1081461,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/426手腕热身（连贯）-打击乐-L1-6-2-A1-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 18,
                    totalMaterialTimeSecond: 0,
                    name: '完整手腕热身',
                    id: 1030640
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '结尾-打击乐-L1-1-7-讲话',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030641,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '结束语',
                        id: 1081462,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/191结尾-打击乐-L1-1-7-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 19,
                    totalMaterialTimeSecond: 0,
                    name: '结束语',
                    id: 1030641
                  }
                ],
                materialList: null,
                sortNo: 13,
                totalMaterialTimeSecond: 0,
                name: '手腕热身练习',
                id: 1030634
              },
              {
                children: [
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制前言-打击乐- L1-1-1-讲话',
                        knowledgePointMaterialRelationId: 1701139355217772500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030643,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习1-前言',
                        id: 1081463,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/86鼓棒控制前言-打击乐-L1-1-1-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 20,
                    totalMaterialTimeSecond: 0,
                    name: '前言',
                    id: 1030643
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习1打击乐- L1-1-2-A1-讲话1',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习1-讲解1',
                        id: 1081464,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/87鼓棒控制练习1打击乐-L1-1-2-A1-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一打击乐- L1-1-2-A1-讲话2',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习1-讲解2',
                        id: 1081465,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/88鼓棒控制练习一打击乐-L1-1-2-A1-讲话2.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A2-讲话-第一步',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第1个动作-鼓棒持拿-指导',
                        id: 1081466,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/166鼓棒控制练习一-打击乐-L1-1-3-A2-讲话-第一步.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A2-讲话-第二步',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第2个动作-鼓棒旋转-指导',
                        id: 1081467,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/167鼓棒控制练习一-打击乐-L1-1-3-A2-讲话-第二步.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A2-讲话-第三步',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第3个动作-自然反弹-指导',
                        id: 1081468,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/168鼓棒控制练习一-打击乐-L1-1-3-A2-讲话-第三步.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A2-讲话-第四步',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第4个动作-反弹到虎口-指导',
                        id: 1081469,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/169鼓棒控制练习一-打击乐-L1-1-3-A2-讲话-第四步.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A2-讲话-第五步',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第5个动作-完整动作-指导',
                        id: 1081470,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/170鼓棒控制练习一-打击乐-L1-1-3-A2-讲话-第五步.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A3-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '过度话术',
                        id: 1081471,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/172鼓棒控制练习一-打击乐-L1-1-3-A3-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A4-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第1个动作-鼓棒持拿-讲话',
                        id: 1081472,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/173鼓棒控制练习一-打击乐-L1-1-3-A4-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A4-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第1个动作-鼓棒持拿-练习',
                        id: 1081473,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/174鼓棒控制练习一-打击乐-L1-1-3-A4-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A5-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第2个动作-鼓棒旋转-讲话',
                        id: 1081474,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/175鼓棒控制练习一-打击乐-L1-1-3-A5-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第2个动作-鼓棒旋转-练习',
                        id: 1081475,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/176鼓棒控制练习一-打击乐-L1-1-3-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A6-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第3个动作-自然反弹-讲话',
                        id: 1081476,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/177鼓棒控制练习一-打击乐-L1-1-3-A6-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A6-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第3个动作-自然反弹-练习',
                        id: 1081477,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/178鼓棒控制练习一-打击乐-L1-1-3-A6-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A7-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第4个动作-反弹到虎口-讲话',
                        id: 1081478,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/179鼓棒控制练习一-打击乐-L1-1-3-A7-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A7-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第4个动作-反弹到虎口-练习',
                        id: 1081479,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/180鼓棒控制练习一-打击乐-L1-1-3-A7-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A8-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第5个动作-完整动作-讲话',
                        id: 1081480,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/181鼓棒控制练习一-打击乐-L1-1-3-A8-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习一-打击乐- L1-1-3-A8-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030644,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '第5个动作-完整动作-练习',
                        id: 1081481,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/182鼓棒控制练习一-打击乐-L1-1-3-A8-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 21,
                    totalMaterialTimeSecond: 0,
                    name: '鼓棒控制练习一',
                    id: 1030644
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐-1-3-A1-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2-前言',
                        id: 1081482,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/101鼓棒控制练习二-打击乐-1-3-A1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐-1-3-A2-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2-讲话1',
                        id: 1081483,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/102鼓棒控制练习二-打击乐-1-3-A2-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐-1-3-A3-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2-讲话2',
                        id: 1081484,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/103鼓棒控制练习二-打击乐-1-3-A3-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B3-示范',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2-第3拍抓握-练习',
                        id: 1081485,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/216鼓棒控制练习二-打击乐-L1-2-3-B3-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B4-讲话',
                        knowledgePointMaterialRelationId: 1701139355221966800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.1-第2拍抓握-讲话1',
                        id: 1081486,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/217鼓棒控制练习二-打击乐-L1-2-3-B4-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B5-讲话',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.1-第2拍抓握-讲话3',
                        id: 1081487,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/219鼓棒控制练习二-打击乐-L1-2-3-B5-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B5-示范',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.1-第2拍抓握-练习',
                        id: 1081488,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/220鼓棒控制练习二-打击乐-L1-2-3-B5-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B6-讲话',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.2-第1拍后半拍抓握-讲话1',
                        id: 1081489,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/221鼓棒控制练习二-打击乐-L1-2-3-B6-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B7-讲话',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.2-第1拍后半拍抓握-讲话2',
                        id: 1081490,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/222鼓棒控制练习二-打击乐-L1-2-3-B7-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B7-示范',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.2-第1拍后半拍抓握 练习',
                        id: 1081491,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/223鼓棒控制练习二-打击乐-L1-2-3-B7-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B8-讲话',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.3-e拍抓握-讲话1',
                        id: 1081492,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/224鼓棒控制练习二-打击乐-L1-2-3-B8-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B9-讲话',
                        knowledgePointMaterialRelationId: 1701139355230355500,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.3-e拍抓握-讲话3',
                        id: 1081493,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/226鼓棒控制练习二-打击乐-L1-2-3-B9-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B9-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.3-e拍抓握 练习',
                        id: 1081494,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/227鼓棒控制练习二-打击乐-L1-2-3-B9-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B10-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.4-击打同时抓握 讲解',
                        id: 1081495,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/228鼓棒控制练习二-打击乐-L1-2-3-B10-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B11-讲话1',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.4-击打同时抓握 讲解',
                        id: 1081496,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/230鼓棒控制练习二-打击乐-L1-2-3-B11-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习二-打击乐- L1-2-3-B11-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030645,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习2.4-击打同时抓握 练习',
                        id: 1081497,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/231鼓棒控制练习二-打击乐-L1-2-3-B11-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 22,
                    totalMaterialTimeSecond: 0,
                    name: '鼓棒控制练习二',
                    id: 1030645
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-1-3-C1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3-手腕单手练习-前言',
                        id: 1081498,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/117鼓棒控制练习三-打击乐-L1-1-3-C1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-3-3-B1-讲话1',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3-手腕单手练习-讲话1',
                        id: 1081499,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/284鼓棒控制练习三-打击乐-L1-3-3-B2-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-3-3-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3-手腕单手练习-练习',
                        id: 1081500,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/285鼓棒控制练习三-打击乐-L1-3-3-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-3-3-C1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.1-四拍连贯练习-讲话',
                        id: 1081501,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/288鼓棒控制练习三-打击乐-L1-3-3-C1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-3-3-C2-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.1-四拍连贯练习-讲话2',
                        id: 1081502,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/289鼓棒控制练习三-打击乐-L1-3-3-C2-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-3-3-C2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.1-四拍连贯练习-练习',
                        id: 1081503,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/290鼓棒控制练习三-打击乐-L1-3-3-C2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-1-4-C1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.2 -手腕四拍连贯练习讲解',
                        id: 1081504,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/123鼓棒控制练习三-打击乐-1-4-C1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-4-3-B2-讲话1',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.2 -手腕四拍连贯练习讲话',
                        id: 1081505,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/345鼓棒控制练习三-打击乐-L1-4-3-B2-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三-打击乐-L1-4-3-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.2 -手腕四拍连贯练习练习',
                        id: 1081506,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/346鼓棒控制练习三-打击乐-L1-4-3-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（一拍）-打击乐-L1-1-4-D2-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.3-手腕一拍连贯练习 讲解（速度70）',
                        id: 1081507,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/126鼓棒控制练习三（一拍）-打击乐-L1-1-4-D2-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（一拍）-打击乐-L1-1-4-D2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.3-手腕一拍连贯练习 示范（速度70）',
                        id: 1081508,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/127鼓棒控制练习三（一拍）-打击乐-L1-1-4-D2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（一拍）-打击乐-L1-1-4-D3-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.3-手腕一拍连贯练习 讲解（速度90）',
                        id: 1081509,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/128鼓棒控制练习三（一拍）-打击乐-L1-1-4-D3-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（一拍）-打击乐-L1-5-3-B2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.3-手腕一拍连贯练习 示范（速度90）',
                        id: 1081510,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/398鼓棒控制练习三（一拍）-打击乐-L1-5-3-B2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（半拍）-打击乐-L1-1-4-D1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.4-手腕一拍连贯练习 讲解',
                        id: 1081511,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/130鼓棒控制练习三（半拍）-打击乐-L1-1-4-D1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（半拍）-打击乐-L1-5-3-C2-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3.4-手腕一拍连贯练习 示范',
                        id: 1081512,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/402鼓棒控制练习三（半拍）-打击乐-L1-5-3-C2-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（连贯）-打击乐-L1-1-4-E1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3所有内容连贯 讲解',
                        id: 1081513,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/132鼓棒控制练习三（连贯）-打击乐-L1-1-4-E1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（完整90速度）-打击乐-L1-7-3-C1-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3所有内容连贯 练习',
                        id: 1081514,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/481鼓棒控制练习三（完整90速度）-打击乐-L1-7-3-C1-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（连贯）-打击乐-L1-1-4-E2-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030646,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3注意事项',
                        id: 1081515,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/134鼓棒控制练习三（连贯）-打击乐-L1-1-4-E2-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 23,
                    totalMaterialTimeSecond: 0,
                    name: '鼓棒控制练习三',
                    id: 1030646
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，一拍）-打击乐-L1-1-4-F1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030647,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1 讲解',
                        id: 1081516,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/135鼓棒控制练习三（十六分音符，一拍）-打击乐-L1-1-4-F1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，一拍）-打击乐-L1-9-3-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030647,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1 练习',
                        id: 1081517,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/572鼓棒控制练习三（十六分音符，一拍）-打击乐-L1-9-3-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 24,
                    totalMaterialTimeSecond: 0,
                    name: '十六分音符-1拍',
                    id: 1030647
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，二拍）-打击乐- 1-4-G1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030648,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX2 讲解',
                        id: 1081518,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/137鼓棒控制练习三（十六分音符，二拍）-打击乐-1-4-G1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，二拍）-打击乐- L1-11-3-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030648,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX2 练习',
                        id: 1081519,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/666鼓棒控制练习三（十六分音符，二拍）-打击乐-L1-11-3-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 25,
                    totalMaterialTimeSecond: 0,
                    name: '十六分音符-2拍',
                    id: 1030648
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，三拍）-打击乐- L1-1-4-H1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030649,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX3 讲解',
                        id: 1081520,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/139鼓棒控制练习三（十六分音符，三拍）-打击乐-L1-1-4-H1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，三拍）-打击乐- L1-13-3-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030649,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX3 练习',
                        id: 1081521,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/766鼓棒控制练习三（十六分音符，三拍）-打击乐-L1-13-3-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 26,
                    totalMaterialTimeSecond: 0,
                    name: '十六分音符-3拍',
                    id: 1030649
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，四拍）-打击乐- L1-1-4-I1-讲话',
                        knowledgePointMaterialRelationId: 1701139355234549800,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030650,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX4 讲解',
                        id: 1081522,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/141鼓棒控制练习三（十六分音符，四拍）-打击乐-L1-1-4-I1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，四拍）-打击乐- L1-15-3-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030650,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX4 练习',
                        id: 1081523,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/866鼓棒控制练习三（十六分音符，四拍）-打击乐-L1-15-3-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 27,
                    totalMaterialTimeSecond: 0,
                    name: '十六分音符-4拍',
                    id: 1030650
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，连贯）-打击乐- L1-1-4-J1-讲话',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX4 练习',
                        id: 1081524,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/143鼓棒控制练习三（十六分音符，连贯）-打击乐-L1-1-4-J1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，连贯）-打击乐- L1-1-4-J1-示范(节拍器80)',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1-Ex4 完整讲解',
                        id: 1081525,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/144鼓棒控制练习三（十六分音符，连贯）-打击乐-L1-1-4-J1-示范(节拍器80).mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，连贯）-打击乐- L1-1-4-J2-示范(节拍器90)',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1-Ex4 完整练习速度90',
                        id: 1081526,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/145鼓棒控制练习三（十六分音符，连贯）-打击乐-L1-1-4-J2-示范(节拍器90).mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，连贯）-打击乐- L1-1-4-J3-示范(节拍器100)',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1-Ex4 完整练习速度10',
                        id: 1081527,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/146鼓棒控制练习三（十六分音符，连贯）-打击乐-L1-1-4-J3-示范(节拍器100).mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '鼓棒控制练习三（十六分音符，连贯）-打击乐- L1-1-4-J4-示范(节拍器110)',
                        knowledgePointMaterialRelationId: 1701139355242938400,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒控制练习3 EX1-Ex4 完整练习速度110',
                        id: 1081528,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/147鼓棒控制练习三（十六分音符，连贯）-打击乐-L1-1-4-J4-示范(节拍器110).mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '结尾-打击乐-L1-1-7-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030651,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '结束语',
                        id: 1081462,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/191结尾-打击乐-L1-1-7-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 28,
                    totalMaterialTimeSecond: 0,
                    name: '十六分音符，连贯练习',
                    id: 1030651
                  }
                ],
                materialList: null,
                sortNo: 20,
                totalMaterialTimeSecond: 0,
                name: '鼓棒控制练习',
                id: 1030642
              },
              {
                children: [
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '四种打法前言-打击乐1-1-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030653,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '四种打法-前言',
                        id: 1081529,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/67四种打法前言-打击乐1-1-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 29,
                    totalMaterialTimeSecond: 0,
                    name: '前言',
                    id: 1030653
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Piston Stroke -打击乐- L1-1-2-A1-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030654,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '鼓棒持拿与演奏姿势',
                        id: 1081530,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/68PistonStroke-打击乐-L1-1-2-A1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Piston Stroke-打击乐-L1-1-4-A2-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030654,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Piston Stroke-讲解',
                        id: 1081531,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/186PistonStroke-打击乐-L1-1-4-A2-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Piston Stroke-打击乐-L1-1-4-A2-示范',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030654,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Piston Stroke-练习',
                        id: 1081532,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/187PistonStroke-打击乐-L1-1-4-A2-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 30,
                    totalMaterialTimeSecond: 0,
                    name: 'Piston Stroke',
                    id: 1030654
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Down Stroke-打击乐-L1-1-2-B1-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030655,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Down Stroke-讲解1',
                        id: 1081533,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/71DownStroke-打击乐-L1-1-2-B1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Down Stroke-打击乐-L1-2-4-A4-讲话1',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030655,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Down Stroke-讲解2',
                        id: 1081534,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/239DownStroke-打击乐-L1-2-4-A4-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Down Stroke-打击乐-L1-2-4-A4-示范',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030655,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Down Stroke-练习',
                        id: 1081535,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/240DownStroke-打击乐-L1-2-4-A4-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 31,
                    totalMaterialTimeSecond: 0,
                    name: 'Down Stroke',
                    id: 1030655
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Tap Stroke-打击乐-L1-1-2-C1-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030656,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Tap Stroke-讲解1',
                        id: 1081536,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/74TapStroke-打击乐-L1-1-2-C1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Tap Stroke-打击乐-L1-3-4-A5-讲话1',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030656,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Tap Stroke-讲解2',
                        id: 1081537,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/301TapStroke-打击乐-L1-3-4-A5-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Tap Stroke-打击乐-L1-3-4-A5-示范',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030656,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Tap Stroke-练习',
                        id: 1081538,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/302TapStroke-打击乐-L1-3-4-A5-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 32,
                    totalMaterialTimeSecond: 0,
                    name: 'Tap Stroke',
                    id: 1030656
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Up Stroke-打击乐-L1-1-2-D1-讲话',
                        knowledgePointMaterialRelationId: 1701139355247132700,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030657,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Up  Stroke-讲解1',
                        id: 1081539,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/77UpStroke-打击乐-L1-1-2-D1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Up Stroke-打击乐-L1-4-4-A6-讲话1',
                        knowledgePointMaterialRelationId: 1701139355251327000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030657,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Up Stroke-讲解2',
                        id: 1081540,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/363Upstroke-打击乐-L1-4-4-A6-讲话1.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: 'Up Stroke-打击乐-L1-4-4-A6-示范',
                        knowledgePointMaterialRelationId: 1701139355251327000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030657,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: 'Up Stroke-练习',
                        id: 1081541,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/364Upstroke-打击乐-L1-4-4-A6-示范.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 33,
                    totalMaterialTimeSecond: 0,
                    name: 'Up Stroke',
                    id: 1030657
                  },
                  {
                    children: null,
                    materialList: [
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '四种打法（连贯）-打击乐-L1-1-3-A1-讲话',
                        knowledgePointMaterialRelationId: 1701139355251327000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030658,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '四种打法连贯-讲解',
                        id: 1081542,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/80四种打法（连贯）-打击乐-L1-1-3-A1-讲话.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '基本打法练习（连贯90速度）-打击乐-L1-5-4-A1-示范',
                        knowledgePointMaterialRelationId: 1701139355251327000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030658,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '四种打法连贯-练习',
                        id: 1081543,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/406基本打法练习（连贯90速度）-打击乐-L1-5-4-A1-示范.mp4',
                        typeCode: 'VIDEO'
                      },
                      {
                        updateTime: '2023-09-11 15:43:18',
                        sn: '结尾-打击乐-L1-1-7-讲话',
                        knowledgePointMaterialRelationId: 1701139355251327000,
                        adviseStudyTimeSecond: 0,
                        knowledgePointId: 1030658,
                        courseTypeCode: 'PERCUSSION_SINGLE',
                        name: '结束语',
                        id: 1081462,
                        type: 0,
                        content:
                          'https://courseware.lexiaoya.cn/191结尾-打击乐-L1-1-7-讲话.mp4',
                        typeCode: 'VIDEO'
                      }
                    ],
                    sortNo: 34,
                    totalMaterialTimeSecond: 0,
                    name: '四种打法（连贯）',
                    id: 1030658
                  }
                ],
                materialList: null,
                sortNo: 29,
                totalMaterialTimeSecond: 0,
                name: '四种基本打法',
                id: 1030652
              }
            ],
            lessonCoursewareDetailIds: null,
            lessonTargetDesc:
              '了解小军鼓的组成、组装和拆解。学习小军鼓的演奏姿势，学习小军鼓的日常保养',
            lessonCoursewareIds: null,
            name: '必学必看',
            id: '1701139354735427585'
          },
          code: 200,
          msg: '',
          nowTime: '2024-04-15 10:33:15'
        }
        data.detail = res.data
        if (res?.data?.lockFlag) {
          postMessage({
            api: 'courseLoading',
            content: {
              show: false,
              type: 'fullscreen'
            }
          })
          Dialog.alert({
            title: '温馨提示',
            message: '课件已锁定'
          }).then(() => {
            goback()
          })
          return
        }
        if (Array.isArray(res?.data?.knowledgePointList)) {
          let index = 0
          data.knowledgePointList = res.data.knowledgePointList.map(
            (n: any) => {
              if (Array.isArray(n.materialList)) {
                n.materialList = n.materialList.map((item: any) => {
                  index++
                  return {
                    ...item,
                    content: item.content,
                    knowledgePointId: [item.knowledgePointId],
                    materialId: item.id,
                    id: index + '',
                    typeCode: item.typeCode || item.type
                  }
                })
              }
              if (Array.isArray(n.children)) {
                n.children = n.children.map((cn: any) => {
                  cn.materialList = cn.materialList.map((item: any) => {
                    index++
                    return {
                      ...item,
                      content: item.content,
                      knowledgePointId: [n.id, item.knowledgePointId],
                      materialId: item.id,
                      id: index + '',
                      typeCode: item.typeCode || item.type
                    }
                  })
                  return cn
                })
              }
              return n
            }
          )
          getItemList()
        }
      } catch (error) {
        console.log(error)
      }
    }

    // ifram事件处理
    const iframeHandle = (ev: MessageEvent) => {
      if (ev.data?.api === 'headerTogge') {
        activeData.model =
          ev.data.show || (ev.data.playState == 'play' ? false : true)
      }
    }

    onMounted(async () => {
      await getDetail()
      // const hasFree = String(data.detail?.accessScope) === '0'
      // if (!hasFree) {
      //   if (state.platformType === 'STUDENT') {
      //     const hasVip = handleCheckVip()
      //     if (!hasVip) {
      //       nextTick(() => {
      //         postMessage({
      //           api: 'courseLoading',
      //           content: {
      //             show: false,
      //             type: 'fullscreen'
      //           }
      //         })
      //       })
      //       return
      //     }
      //   }
      // }
      // getCourseSchedule();
      window.addEventListener('message', iframeHandle)
    })

    const playRef = ref()
    // 返回
    const goback = () => {
      try {
        playRef.value?.handleOut()
      } catch (error) {
        console.log(error)
      }
      postMessage({ api: 'back' })
    }

    const popupData = reactive({
      open: false,
      activeIndex: 0,
      playIndex: 0,
      tabActive: '',
      tabName: '',
      itemActive: '',
      itemName: '',
      guideOpen: false,
      toolOpen: false // 工具弹窗控制
    })

    const stopVideo = (el: HTMLVideoElement) => {
      return new Promise(resolve => {
        if (el.paused) return resolve(true)
        el.onpause = () => {
          console.log('暂停')
          resolve(true)
        }
        el.pause()
      })
    }

    /**停止所有的播放 */
    const handleStop = async () => {
      const videos = document.querySelectorAll('video')
      for (let i = 0; i < videos.length; i++) {
        const videoEle = videos[i] as HTMLVideoElement
        await stopVideo(videoEle)
      }
      console.log('视频暂停完成')
      data.itemList.forEach((item: any) => {
        if (item.typeCode === 'SONG') {
          item.iframeRef?.contentWindow?.postMessage(
            { api: 'setPlayState' },
            '*'
          )
        }
      })
    }
    // 切换素材
    const toggleMaterial = (itemActive: any) => {
      const index = data.itemList.findIndex((n: any) => n.id == itemActive)
      if (index > -1) {
        handleSwipeChange(index)
      }
    }
    /** 延迟收起模态框 */
    const setModelOpen = () => {
      clearTimeout(activeData.timer)
      Toast.clear()
      activeData.timer = setTimeout(() => {
        activeData.model = false
      }, 4000)
    }
    /** 立即收起所有的模态框 */
    const clearModel = () => {
      clearTimeout(activeData.timer)
      Toast.clear()
      activeData.model = false
    }
    const toggleModel = (type = true) => {
      activeData.model = type
    }

    // 去点名,签退
    const gotoRollCall = (pageTag: string) => {
      postMessage({
        api: 'open_app_page',
        content: {
          action: 'app',
          pageTag: pageTag,
          url: '',
          params: JSON.stringify({ courseId: route.query.courseId })
        }
      })
    }

    // 双击
    const handleDbClick = () => {
      if (activeVideoItem.value.typeCode === 'VIDEO') {
        const activeVideoRef = data.videoItemRef?.getPlyrRef()
        if (activeVideoRef) {
          if (activeVideoRef.paused()) {
            activeVideoRef.play()
          } else {
            activeVideoRef.pause()
            Toast('已暂停')
          }
        }
      }
    }

    const effectIndex = ref(0)
    const effects = [
      {
        prev: {
          transform: 'translate3d(0, 0, -800px) rotateX(180deg)'
        },
        next: {
          transform: 'translate3d(0, 0, -800px) rotateX(-180deg)'
        }
      },
      {
        prev: {
          transform: 'translate3d(-100%, 0, -800px)'
        },
        next: {
          transform: 'translate3d(100%, 0, -800px)'
        }
      },
      {
        prev: {
          transform: 'translate3d(-50%, 0, -800px) rotateY(80deg)'
        },
        next: {
          transform: 'translate3d(50%, 0, -800px) rotateY(-80deg)'
        }
      },
      {
        prev: {
          transform: 'translate3d(-100%, 0, -800px) rotateY(-120deg)'
        },
        next: {
          transform: 'translate3d(100%, 0, -800px) rotateY(120deg)'
        }
      },
      // 风车4
      {
        prev: {
          transform: 'translate3d(-50%, 50%, -800px) rotateZ(-14deg)',
          opacity: 0
        },
        next: {
          transform: 'translate3d(50%, 50%, -800px) rotateZ(14deg)',
          opacity: 0
        }
      },
      // 翻页5
      {
        prev: {
          transform: 'translateZ(-800px) rotate3d(0, -1, 0, 90deg)',
          opacity: 0
        },
        next: {
          transform: 'translateZ(-800px) rotate3d(0, 1, 0, 90deg)',
          opacity: 0
        },
        current: { transitionDelay: '700ms' }
      }
    ]

    const acitveTimer = ref()
    // 轮播切换
    const handleSwipeChange = async (index: number) => {
      // 如果是当前正在播放 或者是视频最后一个
      if (popupData.activeIndex == index) return
      await handleStop()
      data.animationState = 'start'
      data.videoState = 'init'
      clearTimeout(acitveTimer.value)
      checkedAnimation(popupData.activeIndex, index)
      nextTick(() => {
        popupData.activeIndex = index

        acitveTimer.value = setTimeout(
          () => {
            popupData.playIndex = index
            const item = data.itemList[index]
            if (item) {
              popupData.tabActive = item.knowledgePointId
              popupData.itemActive = item.id
              popupData.itemName = item.name
              popupData.tabName = item.tabName
              if (item.typeCode == 'SONG') {
                activeData.model = true
              }
            }
            requestAnimationFrame(() => {
              const _effectIndex = effectIndex.value + 1
              effectIndex.value =
                _effectIndex >= effects.length - 1 ? 0 : _effectIndex

              if (item && item.typeCode === 'VIDEO') {
                // 自动播放下一个视频
                clearTimeout(activeData.timer)
                Toast.clear()
                item.autoPlay = true
                data.animationState = 'end'
              }
            })
          },
          activeData.isAnimation ? 850 : 0
        )
      })
    }

    /** 是否有转场动画 */
    const checkedAnimation = (index: number, nextIndex?: number) => {
      nextIndex = nextIndex ? nextIndex : index + 1
      const item = data.itemList[index]
      const nextItem = data.itemList[nextIndex]
      if (nextItem) {
        if (nextItem.knowledgePointId != item.knowledgePointId) {
          activeData.isAnimation = true
          return
        }
        const videoEle = item.videoEle
        const nextVideo = nextItem.videoEle
        if (videoEle && videoEle.duration < 8 && index < nextIndex) {
          activeData.isAnimation = false
        } else if (nextVideo && nextVideo.duration < 8 && index > nextIndex) {
          activeData.isAnimation = false
        } else {
          activeData.isAnimation = true
        }
      } else {
        activeData.isAnimation = item?.adviseStudyTimeSecond < 8 ? false : true
      }
    }

    // 上一个知识点, 下一个知识点
    const handlePreAndNext = (type: string) => {
      if (type === 'up') {
        handleSwipeChange(popupData.activeIndex - 1)
      } else {
        handleSwipeChange(popupData.activeIndex + 1)
      }
    }

    /** 弹窗关闭 */
    const handleClosePopup = () => {
      const item = data.itemList[popupData.activeIndex]
      if (item?.typeCode == 'VIDEO' && !item.videoEle?.paused) {
        setModelOpen()
      }
    }

    /** 教学数据 */
    const studyData = reactive({
      type: '' as ToolType,
      penShow: false
    })

    /** 打开教学工具 */
    const openStudyTool = (item: ToolItem) => {
      const activeItem = data.itemList[popupData.activeIndex]
      // 暂停视频和曲谱的播放
      if (activeItem.typeCode === 'VIDEO' && activeItem.videoEle) {
        activeItem.videoEle.pause()
      }
      if (activeItem.typeCode === 'SONG') {
        activeItem.iframeRef?.contentWindow?.postMessage(
          { api: 'setPlayState' },
          '*'
        )
      }
      clearModel()
      popupData.toolOpen = false
      studyData.type = item.type

      switch (item.type) {
        case 'pen':
          studyData.penShow = true
          break
      }
    }

    /** 关闭教学工具 */
    const closeStudyTool = () => {
      studyData.type = 'init'
      toggleModel()
    }

    const activeVideoItem = computed(() => {
      const item = data.itemList[popupData.activeIndex]
      if (
        item &&
        item.typeCode &&
        item.typeCode.toLocaleUpperCase() === 'VIDEO'
      ) {
        return item
      }
      return {}
    })
    let closeModelTimer: any = null
    return () => (
      <div id="playContent" class={styles.playContent}>
        <div
          class={styles.coursewarePlay}
          style={{ width: parentContainer.width }}
          onClick={() => {
            clearTimeout(closeModelTimer)
            clearTimeout(activeData.timer)
            Toast.clear()
            if (Date.now() - activeData.nowTime < 300) {
              handleDbClick()
              return
            }
            activeData.nowTime = Date.now()
            closeModelTimer = setTimeout(() => {
              activeData.model = !activeData.model
            }, 300)
          }}
        >
          <div class={styles.wraps}>
            <div
              style={
                activeVideoItem.value.typeCode &&
                data.animationState === 'end' &&
                data.videoState === 'play'
                  ? {
                      zIndex: 15,
                      opacity: 1
                    }
                  : { opacity: 0, zIndex: -1 }
              }
              class={styles.itemDiv}
            >
              {/* <VideoItem
                ref={(el: any) => (data.videoItemRef = el)}
                item={activeVideoItem.value}
                activeModel={activeData.model}
                onClose={setModelOpen}
                onPlay={() => {
                  data.videoState = 'play';
                }}
                onPause={() => {
                  clearTimeout(activeData.timer);
                  activeData.model = true;
                }}
                onEnded={() => {
                  const _index = popupData.activeIndex + 1;
                  if (_index < data.itemList.length) {
                    handleSwipeChange(_index);
                  }
                }}
              /> */}
              <VideoPlay
                ref={(el: any) => (data.videoItemRef = el)}
                item={activeVideoItem.value}
                activeModel={activeData.model}
                onPlay={() => {
                  data.videoState = 'play'
                  data.animationState = 'end'
                }}
                onLoadedmetadata={(videoItem: any) => {
                  data.videoState = 'play'
                  activeVideoItem.value.videoEle = videoItem
                  if (!activeVideoItem.value.isprepare) {
                    activeVideoItem.value.isprepare = true
                  }
                }}
                onPause={() => {
                  clearTimeout(activeData.timer)
                  activeData.model = true
                }}
                onEnded={async () => {
                  const _index = popupData.activeIndex + 1
                  if (_index < data.itemList.length) {
                    handleSwipeChange(_index)
                  }
                }}
                onError={() => {
                  // 视屏异常
                  activeVideoItem.value.error = true
                }}
              />
            </div>
            {data.itemList.map((m: any, mIndex: number) => {
              const isRenderItem = Math.abs(popupData.activeIndex - mIndex) < 2
              const isRender = Math.abs(popupData.playIndex - mIndex) < 2
              // 判断是否是当前选中的元素
              const activeEle = popupData.playIndex === mIndex ? true : false

              return isRenderItem ? (
                <div
                  key={'index' + mIndex}
                  data-id={'data' + mIndex}
                  class={[
                    styles.itemDiv,
                    activeEle && styles.itemActive,
                    activeData.isAnimation && styles.acitveAnimation,
                    isRenderItem ? styles.show : styles.hide
                  ]}
                  style={
                    mIndex < popupData.activeIndex
                      ? effects[effectIndex.value].prev
                      : mIndex > popupData.activeIndex
                      ? effects[effectIndex.value].next
                      : {}
                  }
                >
                  {/* {m.type === 'VIDEO' && (
                      <>
                        <VideoPlay
                          ref={(v: any) => (data.videoRefs[mIndex] = v)}
                          item={m}
                          isActive={activeEle}
                          isEmtry={isEmtry}
                          onPrepare={(val) => {
                            m.isprepare = val
                          }}
                          onLoadedmetadata={(videoItem: any) => {
                            m.videoEle = videoItem
                          }}
                          onTogglePlay={(paused: boolean) => {
                            // console.log('播放切换', paused)
                            if (!m.isprepare) {
                              m.isprepare = true
                            }
                            m.autoPlay = false
                            if (paused || popupData.open || popupData.guideOpen) {
                              clearTimeout(activeData.timer)
                            } else {
                              setModelOpen()
                            }
                          }}
                          onEnded={() => {
                            const _index = popupData.activeIndex + 1
                            if (_index < data.itemList.length) {
                              handleSwipeChange(_index)
                            }
                          }}
                          onReset={() => {
                            if (!m.videoEle?.paused) {
                              setModelOpen()
                            }
                          }}
                        />
                        <Transition name="van-fade">
                          {!m.isprepare && (
                            <div class={styles.loadWrap}>
                              <Vue3Lottie animationData={playLoadData}></Vue3Lottie>
                            </div>
                          )}
                        </Transition>
                      </>
                    )} */}
                  <Transition name="van-fade">
                    {m.typeCode === 'VIDEO' &&
                      data.animationState !== 'end' &&
                      data.videoState != 'play' && (
                        <div class={styles.loadWrap}>
                          <Vue3Lottie animationData={playLoadData}></Vue3Lottie>
                        </div>
                      )}
                  </Transition>
                  {isRender && m.typeCode === 'IMG' && <img src={m.content} />}
                  {isRender && m.typeCode === 'SONG' && (
                    <MusicScore
                      activeModel={activeData.model}
                      data-vid={m.id}
                      music={m}
                      onSetIframe={(el: any) => {
                        m.iframeRef = el
                      }}
                    />
                  )}
                </div>
              ) : (
                ''
              )
            })}
          </div>
          <Transition name="right">
            {activeData.model && (
              <div
                class={styles.rightFixedBtns}
                onClick={(e: Event) => {
                  e.stopPropagation()
                  clearTimeout(activeData.timer)
                }}
              >
                <div class={styles.btnsWrap}>
                  <div
                    class={[styles.fullBtn, styles.point]}
                    onClick={() => (popupData.open = true)}
                  >
                    <img src={iconMenu} />
                    <span>知识点</span>
                  </div>
                </div>

                <div class={[styles.btnsWrap, styles.btnsBottom]}>
                  <div
                    class={styles.fullBtn}
                    onClick={() => (popupData.guideOpen = true)}
                  >
                    <img src={iconTouping} />
                    <span>投屏</span>
                  </div>
                  {data.isCourse && (
                    <>
                      <div
                        class={styles.fullBtn}
                        onClick={() => gotoRollCall('student_roll_call')}
                      >
                        <img src={iconDian} />
                        <span>点名</span>
                      </div>
                      <div
                        class={styles.fullBtn}
                        onClick={() => gotoRollCall('sign_out')}
                      >
                        <img src={iconPoint} />
                        <span>签退</span>
                      </div>
                    </>
                  )}
                </div>
              </div>
            )}
          </Transition>

          <Transition name="left">
            {activeData.model && (
              <div
                class={styles.leftFixedBtns}
                onClick={(e: Event) => e.stopPropagation()}
              >
                {popupData.activeIndex != 0 && (
                  <div class={[styles.btnsWrap, styles.prePoint]}>
                    <div
                      class={styles.fullBtn}
                      onClick={() => {
                        // useThrottleFn(() => {
                        //   handlePreAndNext('up')
                        // }, 300)
                        // onChangeSwiper('up')
                        handlePreAndNext('up')
                      }}
                    >
                      <img src={iconUp} />
                      <span style={{ textAlign: 'center' }}>上一个</span>
                    </div>
                  </div>
                )}
                {popupData.activeIndex != data.itemList.length - 1 && (
                  <div class={styles.btnsWrap}>
                    <div
                      class={styles.fullBtn}
                      onClick={() => {
                        // console.log('click down')
                        // useThrottleFn(() => {
                        //   console.log('click down pass')
                        //   handlePreAndNext('down')
                        // }, 300)
                        // onChangeSwiper('down')
                        handlePreAndNext('down')
                      }}
                    >
                      <span style={{ textAlign: 'center' }}>下一个</span>
                      <img src={iconDown} />
                    </div>
                  </div>
                )}
              </div>
            )}
          </Transition>
        </div>

        <div
          style={{ transform: activeData.model ? '' : 'translateY(-100%)' }}
          id="coursePlayHeader"
          class={styles.headerContainer}
          ref={headeRef}
        >
          <div class={styles.backBtn} onClick={() => goback()}>
            <Icon name={iconBack} />
            返回
          </div>
          {data.isCourse && (
            <PlayRecordTime ref={playRef} list={data.knowledgePointList} />
          )}
          <div
            class={styles.menu}
            onClick={() => {
              const _effectIndex = effectIndex.value + 1
              effectIndex.value =
                _effectIndex >= effects.length - 1 ? 0 : _effectIndex
              setModelOpen()
            }}
          >
            {popupData.tabName}
          </div>

          {state.platformType === 'TEACHER' && (
            <div
              class={styles.headRight}
              onClick={(e: Event) => {
                e.stopPropagation()
                clearTimeout(activeData.timer)
              }}
            >
              {/* <div
                class={styles.rightBtn}
                onClick={() => (popupData.guideOpen = true)}
              >
                <img src={iconTouping} />
              </div> */}
              {/* <div
                class={styles.rightBtn}
                onClick={() => {
                  openStudyTool({
                    type: 'pen',
                    icon: iconPen,
                    name: '批注'
                  });
                }}>
                <img src={iconPen} />
              </div> */}
              {/* <div class={styles.rightBtn} onClick={() => (popupData.toolOpen = true)}>
                <img src={iconMore} />
              </div> */}
            </div>
          )}
        </div>

        {/* 更多弹窗 */}
        <Popup
          class={styles.popupMore}
          overlayClass={styles.overlayClass}
          position="right"
          round
          v-model:show={popupData.toolOpen}
          onClose={handleClosePopup}
        >
          <Tool onHandleTool={openStudyTool} />
        </Popup>

        <Popup
          class={styles.popup}
          style={{ background: 'rgba(0,0,0, 0.7)' }}
          overlayClass={styles.overlayClass}
          position="right"
          round
          v-model:show={popupData.open}
          onClose={handleClosePopup}
        >
          <Points
            data={data.knowledgePointList}
            tabActive={popupData.tabActive}
            itemActive={popupData.itemActive}
            onHandleSelect={(res: any) => {
              // onChangeSwiper('change', res.itemActive)
              popupData.open = false
              toggleMaterial(res.itemActive)
            }}
          />
        </Popup>

        <Popup
          class={styles.popup}
          overlayClass={styles.overlayClass}
          position="right"
          round
          v-model:show={popupData.guideOpen}
          onClose={handleClosePopup}
        >
          <OGuide />
        </Popup>

        {studyData.penShow && (
          <Pen show={studyData.type === 'pen'} close={() => closeStudyTool()} />
        )}
      </div>
    )
  }
})
